@@ -74,7 +74,7 @@ typedef struct {
    unsigned int depth_offset;
    unsigned int w;
    unsigned int h;
-   unsigned int pitch;
+   unsigned int pitch; /* Pitch of front buffer in units of pixels */
    unsigned int pitch_bits;
    unsigned int back_pitch;
    unsigned int depth_pitch;
@@ -138,6 +138,15 @@ typedef struct {
 	int third_offset;
 	int third_size;
 	unsigned int third_tiled;
+
+	/* buffer object handles for the static buffers.  May change
+	 * over the lifetime of the client, though it doesn't in our current
+	 * implementation.
+	 */
+	unsigned int front_bo_handle;
+	unsigned int back_bo_handle;
+	unsigned int third_bo_handle;
+	unsigned int depth_bo_handle;
 } drmI830Sarea;
 
 /* Flags for perf_boxes
